summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-10-17 09:00:48 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-10-17 09:09:54 -0500
commit279205664f9045454eaa60a36850412bf6a354fb (patch)
tree5bed065871a968794c1519c25cb3a8a3b0caccf4
parentf7a7bb0384c1e26082d06a05a28c279ce323ec00 (diff)
downloadlibpng-1.6.14rc02.tar.gz
[libpng16] Imported from libpng-1.6.14rc02.tarv1.6.14rc02
-rw-r--r--ANNOUNCE20
-rw-r--r--CHANGES4
-rw-r--r--CMakeLists.txt2
-rw-r--r--LICENSE4
-rw-r--r--configure.ac4
-rw-r--r--libpngpf.34
-rw-r--r--png.52
-rw-r--r--png.c6
-rw-r--r--png.h18
-rw-r--r--pngconf.h2
-rw-r--r--pngtest.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt10
-rw-r--r--scripts/def.dfn2
-rw-r--r--scripts/libpng-config-head.in2
-rw-r--r--scripts/libpng.pc.in2
-rw-r--r--scripts/makefile.ne12bsd2
-rw-r--r--scripts/makefile.netbsd2
-rw-r--r--scripts/makefile.openbsd2
-rw-r--r--scripts/pnglibconf.h.prebuilt4
-rw-r--r--scripts/symbols.def2
22 files changed, 54 insertions, 46 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index a8057db32..a4a3cf5f7 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,4 +1,4 @@
-Libpng 1.6.14rc01 - October 15, 2014
+Libpng 1.6.14rc02 - October 17, 2014
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -8,20 +8,20 @@ Files available for download:
Source files with LF line endings (for Unix/Linux) and with a
"configure" script
- 1.6.14rc01.tar.xz (LZMA-compressed, recommended)
- 1.6.14rc01.tar.gz
+ 1.6.14rc02.tar.xz (LZMA-compressed, recommended)
+ 1.6.14rc02.tar.gz
Source files with CRLF line endings (for Windows), without the
"configure" script
- lp1614r01.7z (LZMA-compressed, recommended)
- lp1614r01.zip
+ lp1614r02.7z (LZMA-compressed, recommended)
+ lp1614r02.zip
Other information:
- 1.6.14rc01-README.txt
- 1.6.14rc01-LICENSE.txt
- libpng-1.6.14rc01-*.asc (armored detached GPG signatures)
+ 1.6.14rc02-README.txt
+ 1.6.14rc02-LICENSE.txt
+ libpng-1.6.14rc02-*.asc (armored detached GPG signatures)
Changes since the last public release (1.6.13):
@@ -71,6 +71,10 @@ Version 1.6.14beta07 [October 7, 2014]
Version 1.6.14rc01 [October 15, 2014]
Fixed some typos in comments.
+Version 1.6.14rc02 [October 17, 2014]
+ Changed png_convert_to_rfc_1123() to png_convert_to_rfc_1123_buffer()
+ in the manual, to reflect the change made in libpng-1.6.0.
+
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CHANGES b/CHANGES
index 18e0dab47..68f3fc930 100644
--- a/CHANGES
+++ b/CHANGES
@@ -5024,6 +5024,10 @@ Version 1.6.14beta07 [October 7, 2014]
Version 1.6.14rc01 [October 15, 2014]
Fixed some typos in comments.
+Version 1.6.14rc02 [October 17, 2014]
+ Changed png_convert_to_rfc_1123() to png_convert_to_rfc_1123_buffer()
+ in the manual, to reflect the change made in libpng-1.6.0.
+
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
https://lists.sourceforge.net/lists/listinfo/png-mng-implement
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 6e9b101fb..88527b05d 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -253,7 +253,7 @@ endif(NOT WIN32 OR CYGWIN OR MINGW)
# SET UP LINKS
if(PNG_SHARED)
set_target_properties(${PNG_LIB_NAME} PROPERTIES
-# VERSION 16.${PNGLIB_RELEASE}.1.6.14rc01
+# VERSION 16.${PNGLIB_RELEASE}.1.6.14rc02
VERSION 16.${PNGLIB_RELEASE}.0
SOVERSION 16
CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index bcd035af9..6601c5541 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.6.14rc01, October 15, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.6.14rc02, October 17, 2014, are
Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-October 15, 2014
+October 17, 2014
diff --git a/configure.ac b/configure.ac
index 39323d49f..480a0da93 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,7 +18,7 @@ AC_PREREQ([2.68])
dnl Version number stuff here:
-AC_INIT([libpng],[1.6.14rc01],[png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng],[1.6.14rc02],[png-mng-implement@lists.sourceforge.net])
AC_CONFIG_MACRO_DIR([scripts])
# libpng does not follow GNU file name conventions (hence 'foreign')
@@ -39,7 +39,7 @@ dnl automake, so the following is not necessary (and is not defined anyway):
dnl AM_PREREQ([1.11.2])
dnl stop configure from automagically running automake
-PNGLIB_VERSION=1.6.14rc01
+PNGLIB_VERSION=1.6.14rc02
PNGLIB_MAJOR=1
PNGLIB_MINOR=6
PNGLIB_RELEASE=14
diff --git a/libpngpf.3 b/libpngpf.3
index 0bca82f2a..ee057b4d8 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "October 15, 2014"
+.TH LIBPNGPF 3 "October 17, 2014"
.SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.6.14rc01
+libpng \- Portable Network Graphics (PNG) Reference Library 1.6.14rc02
(private functions)
.SH SYNOPSIS
\fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index 947512d74..ce135e927 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "October 15, 2014"
+.TH PNG 5 "October 17, 2014"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 1828e907a..5062ae892 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
#include "pngpriv.h"
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_14rc01 Your_png_h_is_not_version_1_6_14rc01;
+typedef png_libpng_version_1_6_14rc02 Your_png_h_is_not_version_1_6_14rc02;
/* Tells libpng that we have already handled the first "num_bytes" bytes
* of the PNG file signature. If the PNG data is embedded into another
@@ -773,13 +773,13 @@ png_get_copyright(png_const_structrp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.6.14rc01 - October 15, 2014" PNG_STRING_NEWLINE \
+ "libpng version 1.6.14rc02 - October 17, 2014" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2014 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.6.14rc01 - October 15, 2014\
+ return "libpng version 1.6.14rc02 - October 17, 2014\
Copyright (c) 1998-2014 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 546b3f786..6fa1e7250 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.6.14rc01 - October 15, 2014
+ * libpng version 1.6.14rc02 - October 17, 2014
*
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index 1dd461657..8db6fbb2b 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1991,4 +1991,4 @@ main(void)
#endif
/* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_6_14rc01 Your_png_h_is_not_version_1_6_14rc01;
+typedef png_libpng_version_1_6_14rc02 Your_png_h_is_not_version_1_6_14rc02;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 2d14337b0..cbda30b59 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.6.14rc01 - October 15, 2014
+libpng version 1.6.14rc02 - October 17, 2014
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 2286bdac8..998333b94 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.6.14rc01 - October 15, 2014
+ * libpng version 1.6.14rc02 - October 17, 2014
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 767656787..6ab144890 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
-Makefiles for libpng version 1.6.14rc01 - October 15, 2014
+Makefiles for libpng version 1.6.14rc02 - October 17, 2014
pnglibconf.h.prebuilt => Stores configuration settings
makefile.linux => Linux/ELF makefile
- (gcc, creates libpng16.so.16.1.6.14rc01)
+ (gcc, creates libpng16.so.16.1.6.14rc02)
makefile.gcc => Generic makefile (gcc, creates static libpng.a)
makefile.knr => Archaic UNIX Makefile that converts files with
ansi2knr (Requires ansi2knr.c from
@@ -33,12 +33,12 @@ pnglibconf.h.prebuilt => Stores configuration settings
makefile.os2 => OS/2 Makefile (gcc and emx, requires libpng.def)
makefile.sco => For SCO OSr5 ELF and Unixware 7 with Native cc
makefile.sggcc => Silicon Graphics (gcc,
- creates libpng16.so.16.1.6.14rc01)
+ creates libpng16.so.16.1.6.14rc02)
makefile.sgi => Silicon Graphics IRIX makefile (cc, creates static lib)
makefile.solaris => Solaris 2.X makefile (gcc,
- creates libpng16.so.16.1.6.14rc01)
+ creates libpng16.so.16.1.6.14rc02)
makefile.so9 => Solaris 9 makefile (gcc,
- creates libpng16.so.16.1.6.14rc01)
+ creates libpng16.so.16.1.6.14rc02)
makefile.std => Generic UNIX makefile (cc, creates static libpng.a)
makefile.sunos => Sun makefile
makefile.32sunu => Sun Ultra 32-bit makefile
diff --git a/scripts/def.dfn b/scripts/def.dfn
index 7d32b5a10..b4173672c 100644
--- a/scripts/def.dfn
+++ b/scripts/def.dfn
@@ -21,7 +21,7 @@ PNG_DFN "OS2 DESCRIPTION "PNG image compression library""
PNG_DFN "OS2 CODE PRELOAD MOVEABLE DISCARDABLE"
PNG_DFN ""
PNG_DFN "EXPORTS"
-PNG_DFN ";Version 1.6.14rc01"
+PNG_DFN ";Version 1.6.14rc02"
#define PNG_EXPORTA(ordinal, type, name, args, attributes)\
PNG_DFN "@" SYMBOL_PREFIX "@@" name "@"
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 8137e57d4..affdb9b12 100644
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
# Modeled after libxml-config.
-version=1.6.14rc01
+version=1.6.14rc02
prefix=""
libdir=""
libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index c9fc87f5c..d193a9db0 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@ includedir=@includedir@/libpng16
Name: libpng
Description: Loads and saves PNG files
-Version: 1.6.14rc01
+Version: 1.6.14rc02
Libs: -L${libdir} -lpng16
Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 160e0a800..542bb44cb 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include/libpng16
LIB= png16
SHLIB_MAJOR= 0
-SHLIB_MINOR= 1.6.14rc01
+SHLIB_MINOR= 1.6.14rc02
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index d086b7501..c54f92409 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@ INCSDIR=${LOCALBASE}/include
LIB= png
SHLIB_MAJOR= 16
-SHLIB_MINOR= 1.6.14rc01
+SHLIB_MINOR= 1.6.14rc02
SRCS= png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index c537a921f..4247ce7fb 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@ LIBDIR= ${PREFIX}/lib
MANDIR= ${PREFIX}/man/cat
SHLIB_MAJOR= 16
-SHLIB_MINOR= 1.6.14rc01
+SHLIB_MINOR= 1.6.14rc02
LIB= png
SRCS= png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index bd36f6440..a056b8ce6 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,8 +1,8 @@
-/* libpng 1.6.14rc01 STANDARD API DEFINITION */
+/* libpng 1.6.14rc02 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* Libpng version 1.6.14rc01 - October 15, 2014 */
+/* Libpng version 1.6.14rc02 - October 17, 2014 */
/* Copyright (c) 1998-2014 Glenn Randers-Pehrson */
diff --git a/scripts/symbols.def b/scripts/symbols.def
index c31665893..c7a12a6a8 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -1,4 +1,4 @@
-;Version 1.6.14rc01
+;Version 1.6.14rc02
;--------------------------------------------------------------
; LIBPNG symbol list as a Win32 DEF file
; Contains all the symbols that can be exported from libpng
diff --git a/png.h b/png.h
index 0c25cb00f..f23a4f525 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.6.14rc01 - October 15, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.6.14rc01 - October 15, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -236,7 +236,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.6.14rc01, October 15, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -348,13 +348,13 @@
* Y2K compliance in libpng:
* =========================
*
- * October 15, 2014
+ * October 17, 2014
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
* upward through 1.6.14rc01 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -416,9 +416,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.6.14rc01"
+#define PNG_LIBPNG_VER_STRING "1.6.14rc02"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.6.14rc01 - October 15, 2014\n"
+ " libpng version 1.6.14rc02 - October 17, 2014\n"
#define PNG_LIBPNG_VER_SONUM 16
#define PNG_LIBPNG_VER_DLLNUM 16
@@ -432,7 +432,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 01
+#define PNG_LIBPNG_VER_BUILD 02
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -562,7 +562,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_6_14rc01;
+typedef char* png_libpng_version_1_6_14rc02;
/* Basic control structions. Read libpng-manual.txt or libpng.3 for more info.
*
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.6.14rc01 - October 15, 2014
+ * libpng version 1.6.14rc02 - October 17, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.6.14rc01 - October 15, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.6.14rc02 - October 17, 2014: Glenn
* See also "Contributing Authors", below.
*
@@ -236,7 +236,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.6.14rc01, October 15, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.6.14rc02, October 17, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
@@ -348,13 +348,13 @@
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.6.14rc01 are Y2K compliant. It is my belief that
+ * upward through 1.6.14rc02 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*